#[repr(C)]pub struct URL_COMPONENTSA {Show 15 fields
pub dwStructSize: DWORD,
pub lpszScheme: LPSTR,
pub dwSchemeLength: DWORD,
pub nScheme: c_int,
pub lpszHostName: LPSTR,
pub dwHostNameLength: DWORD,
pub nPort: USHORT,
pub lpszUserName: LPSTR,
pub dwUserNameLength: DWORD,
pub lpszPassword: LPSTR,
pub dwPasswordLength: DWORD,
pub lpszUrlPath: LPSTR,
pub dwUrlPathLength: DWORD,
pub lpszExtraInfo: LPSTR,
pub dwExtraInfoLength: DWORD,
}Expand description
Components of a parsed URL string, used with InternetCrackUrlA.
Fields
dwStructSize: DWORDSize of this structure, in bytes.
lpszScheme: LPSTRPointer to a buffer that receives the URL scheme (e.g., “http”).
dwSchemeLength: DWORDLength of the scheme string, in characters.
nScheme: c_intScheme type value as determined by the API.
lpszHostName: LPSTRPointer to a buffer that receives the host name.
dwHostNameLength: DWORDLength of the host name string, in characters.
nPort: USHORTPort number extracted from the URL.
lpszUserName: LPSTRPointer to a buffer that receives the username, if present.
dwUserNameLength: DWORDLength of the username string, in characters.
lpszPassword: LPSTRPointer to a buffer that receives the password, if present.
dwPasswordLength: DWORDLength of the password string, in characters.
lpszUrlPath: LPSTRPointer to a buffer that receives the URL path.
dwUrlPathLength: DWORDLength of the URL path string, in characters.
lpszExtraInfo: LPSTRPointer to a buffer that receives extra info or query parameters.
dwExtraInfoLength: DWORDLength of the extra info string, in characters.