#[repr(C)]pub struct RUNTIME_FUNCTION {
pub BeginAddress: DWORD,
pub EndAddress: DWORD,
pub UnwindData: DWORD,
}Expand description
Represents an entry in the function table on 64-bit Windows.
Fields
BeginAddress: DWORDThe address of the start of the function.
EndAddress: DWORDThe address of the end of the function.
UnwindData: DWORDThe address of the unwind information for the function.