#[repr(C)]pub struct UNICODE_STRING {
pub Length: u16,
pub MaximumLength: u16,
pub Buffer: *mut u16,
}Expand description
Represents a counted, UTF-16 encoded Unicode string buffer
Fields
Length: u16Length, in bytes, of the string stored in Buffer.
This does not include the terminating null character.
MaximumLength: u16Maximum size, in bytes, allocated for Buffer.
This value typically includes space for the terminating null character.
Buffer: *mut u16Pointer to a wide-character string buffer (UTF-16 encoded).