URL_COMPONENTSA

Struct URL_COMPONENTSA 

#[repr(C)]
pub struct URL_COMPONENTSA {
Show 15 fields pub dwStructSize: DWORD, pub lpszScheme: LPSTR, pub dwSchemeLength: DWORD, pub nScheme: c_int, pub lpszHostName: LPSTR, pub dwHostNameLength: DWORD, pub nPort: USHORT, pub lpszUserName: LPSTR, pub dwUserNameLength: DWORD, pub lpszPassword: LPSTR, pub dwPasswordLength: DWORD, pub lpszUrlPath: LPSTR, pub dwUrlPathLength: DWORD, pub lpszExtraInfo: LPSTR, pub dwExtraInfoLength: DWORD,
}
Describes the components of a parsed URL string.

The URL_COMPONENTSA structure is used with the Windows API function InternetCrackUrlA to retrieve individual parts of a URL.

Fields

dwStructSize: DWORD

Size of this structure, in bytes.

lpszScheme: LPSTR

Pointer to a buffer that receives the URL scheme (e.g., “http”).

dwSchemeLength: DWORD

Length of the scheme string, in characters.

nScheme: c_int

Scheme type value as determined by the API.

lpszHostName: LPSTR

Pointer to a buffer that receives the host name (e.g., “example.com”).

dwHostNameLength: DWORD

Length of the host name string, in characters.

nPort: USHORT

Port number extracted from the URL.

lpszUserName: LPSTR

Pointer to a buffer that receives the username, if present in the URL.

dwUserNameLength: DWORD

Length of the username string, in characters.

lpszPassword: LPSTR

Pointer to a buffer that receives the password, if present in the URL.

dwPasswordLength: DWORD

Length of the password string, in characters.

lpszUrlPath: LPSTR

Pointer to a buffer that receives the URL path (e.g., “/index.html”).

dwUrlPathLength: DWORD

Length of the URL path string, in characters.

lpszExtraInfo: LPSTR

Pointer to a buffer that receives any extra information or query parameters (e.g., “?id=1”).

dwExtraInfoLength: DWORD

Length of the extra info string, in characters.