#[repr(C)]pub struct URL_COMPONENTSA {Show 15 fields
pub dwStructSize: DWORD,
pub lpszScheme: LPSTR,
pub dwSchemeLength: DWORD,
pub nScheme: c_int,
pub lpszHostName: LPSTR,
pub dwHostNameLength: DWORD,
pub nPort: USHORT,
pub lpszUserName: LPSTR,
pub dwUserNameLength: DWORD,
pub lpszPassword: LPSTR,
pub dwPasswordLength: DWORD,
pub lpszUrlPath: LPSTR,
pub dwUrlPathLength: DWORD,
pub lpszExtraInfo: LPSTR,
pub dwExtraInfoLength: DWORD,
}Expand description
Describes the components of a parsed URL string.
The URL_COMPONENTSA structure is used with the Windows API function
InternetCrackUrlA to retrieve individual parts of a URL.
Fields
dwStructSize: DWORDSize of this structure, in bytes.
lpszScheme: LPSTRPointer to a buffer that receives the URL scheme (e.g., “http”).
dwSchemeLength: DWORDLength of the scheme string, in characters.
nScheme: c_intScheme type value as determined by the API.
lpszHostName: LPSTRPointer to a buffer that receives the host name (e.g., “example.com”).
dwHostNameLength: DWORDLength of the host name string, in characters.
nPort: USHORTPort number extracted from the URL.
lpszUserName: LPSTRPointer to a buffer that receives the username, if present in the URL.
dwUserNameLength: DWORDLength of the username string, in characters.
lpszPassword: LPSTRPointer to a buffer that receives the password, if present in the URL.
dwPasswordLength: DWORDLength of the password string, in characters.
lpszUrlPath: LPSTRPointer to a buffer that receives the URL path (e.g., “/index.html”).
dwUrlPathLength: DWORDLength of the URL path string, in characters.
lpszExtraInfo: LPSTRPointer to a buffer that receives any extra information or query parameters (e.g., “?id=1”).
dwExtraInfoLength: DWORDLength of the extra info string, in characters.